@@ -19,7 +19,7 @@ def TikAPI(apiKey: str):
 
 			nextCursorParams = {}
 
-			if body.get("hasMore"):
+			if body.get("hasMore") or body.get("has_more"):
 				nextCursor = body.get("offset", body.get("cursor"))
 				if not nextCursor:
 					return None
